@@ -10,7 +10,7 @@ use Zed::Config::Space;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub _macro
 {
@@ -146,38 +146,38 @@ Zed - Remote execution shell over SSH
   (Type 'help' to show more commands)
 
   # set your username used by ssh/scp
-  > nobody@zed#> set username foo
+  > nobody@zed> set username foo
 
   # add a group servers
-  > foo@zed#> add first_group
+  > foo@zed> add first_group
   myserver1.bar.com
   myserver{2~9}.bar.com
   [CTRL+D]
   add servers hosts[9] suc!
 
   # show the servers added just now
-  > foo@zed#> dump first_group
+  > foo@zed> dump first_group
 
   # use a group as your target
-  > foo@zed#> use first_group 
+  > foo@zed> use first_group 
 
   # run command over ssh
-  > foo@zed#> cmd ls /tmp
+  > foo@zed> cmd ls /tmp
 
   # run command with sudo
-  > foo@zed#> cmd sudo ls /root
+  > foo@zed> cmd sudo ls /root
 
   # port detection
-  > foo@zed#> port 80
+  > foo@zed> port 80
   
   # checkout the results to group
-  > foo@zed#> checkout
+  > foo@zed> checkout
 
   # then you can use the suc group
-  > foo@zed#> use default.suc
+  > foo@zed> use default.suc
 
   # show more commands
-  > type
+  > help
 
 =head1 DESCRIPTION
 
@@ -201,6 +201,40 @@ Features below:
 
 (Servers will not disconnect until you quit. So Large mount of servers may cause memory problem)
 
+=head1 ENV
+
+  $ENV{ZED_HOME}: zed working dir, default $HOME/.zed
+
+=head1 CONF
+
+  $ENV{ZED_HOME}/Space: 
+
+    #targets defined here.
+    ---
+    foo:
+    - 127.0.0.1
+    none: ~
+
+  $ENV{ZED_HOME}/Env: 
+
+    ---
+    username: nobody
+
+    #idc is the name of a regex to identify servers group.
+    #batch idc 1. Pick 1 server of each group identified by regex idc to build new targets.
+    batch:
+      idc: ^.+?\..+?\.(.+?)\.
+
+    #short command to complete real command
+    macro:
+      ip: cmd /sbin/ip addr|grep inet|grep -v 127.0.0.1|awk "{print \$2}"|awk -F"/" "{print \$1}"
+
+    #plugins to load
+    plugin:
+    - Zed::Plugin::Sys::Echo
+    ...
+    - Zed::Plugin::Host::Checkout
+
 =head1 AUTHOR
 
 SiYu Zhao E<lt>zuyis@cpan.orgE<gt>
